@@ -1,22 +1,31 @@
 package Net::Connector;
-use strict;
+use 5.016;
 use warnings;
 
 =encoding utf8
+
 =head1 NAME
+
 Net::Connector - Network automation login toolkit
+
 =head1 SYNOPSIS
-  # Net::Connector::Role
+
+  # Net::Connector::Role, UNDER DEVELOPMENT
     该项目使用 Moose 编写相关代码逻辑，当前支持的功能如下：
     1、支持定义enable模式；
     2、支持初阶的错误代码拦截；
     3、支持用户自定义自动交互运行代码；
     4、支持 interact 模式；
-    5、支持灵活扩展多厂商及不同厂商下的任务编排：抓取运行环境、配置
+    5、支持灵活扩展多厂商及不同厂商下的任务编排：抓取运行环境、配置;
+
 =head1 DESCRIPTION
-    待完善功能描述和模块使用概要
+
+    待完善功能描述和模块使用概要, EMAIL => 968826@gmail.com
+
 =head1 SEE ALSO
+
 L<Net::Connector>, L<https://github.com/snmpd/net-connector>.
+
 =cut
 
 # ABSTRACT: turns baubles into trinkets
